@@ -1,6 +1,5 @@
-# Copyright 2016-2019 Laszlo Attila Toth
+# Copyright 2016-2022 Laszlo Attila Toth
 # Distributed under the terms of the GNU Lesser General Public License v3
-import typing
 
 from dewi_logparsers.loghandler import LogParserModule
 from dewi_module_framework.messages import Level
@@ -23,7 +22,7 @@ class RebootModule(LogParserModule):
     def start(self):
         self._reboots = list()
 
-    def system_reboot(self, time: str, program: str, pid: typing.Optional[str], msg: str):
+    def system_reboot(self, time: str, program: str, pid: str | None, msg: str):
         self._reboots.append(time)
 
     def finish(self):
